4.3. umbra.components.addons.projectsExplorer.views — Umbra 1.0.9 documentation

# 4.3. umbra.components.addons.projectsExplorer.views

views.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `umbra.components.factory.projectsExplorer.projectsExplorer.ProjectsExplorer` Component Interface class View.

Others:

## 4.3.1. Module Attributes

`umbra.components.addons.projectsExplorer.views.` `LOGGER`

## 4.3.2. Classes

class `umbra.components.addons.projectsExplorer.views.` `Projects_QTreeView`(parent, model=None, readOnly=False, message=None)

  Bases: `umbra.ui.views.Abstract_QTreeView`

  Defines the view for Projects.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. model (QObject) – Model. readOnly (bool) – View is read only. message (unicode) – View default message when Model is empty.

  `treeViewIndentation`

    Property for self.__treeViewIndentation attribute.

    Returns: | self.__treeViewIndentation.
    Return type: | int

  `setModel`(model)

    Reimplements the umbra.ui.views.Abstract_QTreeView.setModel method.

    Parameters: | model (QObject) – Model to set.